C*    SFS1LU - LOOK UP DISK FILE
C
      SUBROUTINE SFS1LU (ID, BUFR, NBUF, NAME, NCH, N1WPR, LUN, NERR)
C
C     OPEN DISK FILE FOR BUFFERED BLOCK READ/WRITE
C
C	ID = 6 WORD ID BLOCK (SHOULD BE REAL IN CALLING PROGRAM)
C	BUFR = BUFFER AREA , MULTIPLE OF 128R WORDS
C	NBUF = NUMBER OF 128R WORD BLOCKS IN BUFR
C	NAME = FILE-SPEC, WITHOUT DB0: PREFACE
C	NCH  = NO. OF CHARS IN NAME, IF 0, OPEN TEMP FILE
C	N1WPR = NO. OF INTEGER WORDS/RECORD
C	LUN = LOGICAL UNIT NUMBER
C	NERR = ERR RETURNED ON OPEN, 0 OKAY
C
      BYTE IBNAM, NAME
      DIMENSION ID(6), BUFR(1), NAME(1), IBNAM(36)
      CALL SIVFL (0, ID, 6)
C
      ID(1) = NIWIJ (ID, BUFR) + 1
      ID(2) = NBUF
      ID(3) = N1WPR
C     ID(4) = MULTIPLE BLOCK NO. OF BLOCK IN BUFR
      ID(5) = LUN
C     ID(6) = NWA, FROM DBKRD
C
      RETURN
      END